@@ -89,7 +89,26 @@ class ABroker(ABC):
         ----------
         func : Callable
             The callback function. It must accept a
+            :class:`~algotradepy.trade.Trade` and a
             :class:`~algotradepy.trade.TradeStatus` as its sole positional
+            arguments.
+        fn_kwargs : dict
+            The keyword arguments to pass to the callback function along with
+            the positional arguments.
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def subscribe_to_position_updates(
+        self, func: Callable, fn_kwargs: Optional[Dict] = None,
+    ):
+        """Subscribe to receiving position updates.
+
+        Parameters
+        ----------
+        func : Callable
+            The callback function. It must accept a
+            :class:`~algotradepy.objects.Position` as its sole positional
             argument.
         fn_kwargs : dict
             The keyword arguments to pass to the callback function along with
@@ -137,6 +156,7 @@ class ABroker(ABC):
         float
             The current position for the specified symbol.
         """
+        # TODO: refactor to return list of Position objects
         raise NotImplementedError
 
     @abstractmethod
