@@ -1,13 +1,11 @@
 from algotradepy.historical.providers.yahoo_provider import (
     YahooHistoricalProvider,
 )
-from algotradepy.historical.providers.iex_provider import IEXHistoricalProvider
 from algotradepy.historical.loaders import HistoricalRetriever
 from algotradepy.historical.transformers import HistoricalAggregator
 
 __all__ = [
     "YahooHistoricalProvider",
-    "IEXHistoricalProvider",
     "HistoricalRetriever",
     "HistoricalAggregator",
 ]
