@@ -11,6 +11,7 @@ from algotradepy.contracts import (
     Currency,
     ForexContract,
 )
+from algotradepy.objects import Position
 from algotradepy.orders import (
     AnOrder,
     LimitOrder,
@@ -186,6 +187,45 @@ def spy_stock_contract():
     return contract
 
 
+def test_open_positions(
+    master_broker,
+    non_master_ib_test_broker,
+    spy_stock_contract,
+    ib_stk_contract_spy,
+    ib_mkt_buy_order_1,
+    ib_mkt_sell_order_1,
+):
+    from ib_insync import OrderStatus
+
+    initial_positions = master_broker.open_positions
+
+    if len(initial_positions) != 0:
+        raise ValueError("Must run tests on a blank paper-trading account.")
+
+    trade = non_master_ib_test_broker.placeOrder(
+        contract=ib_stk_contract_spy, order=ib_mkt_buy_order_1,
+    )
+
+    while trade.orderStatus.status not in OrderStatus.DoneStates:
+        non_master_ib_test_broker.sleep()
+
+    positions = master_broker.open_positions
+
+    assert len(positions) == 1
+
+    position = positions[0]
+
+    assert position.contract == spy_stock_contract
+    assert position.position == 1
+
+    trade = non_master_ib_test_broker.placeOrder(
+        contract=ib_stk_contract_spy, order=ib_mkt_sell_order_1,
+    )
+
+    while trade.orderStatus.status not in OrderStatus.DoneStates:
+        non_master_ib_test_broker.sleep()
+
+
 def test_subscribe_to_new_trades_non_master_raises(non_master_broker):
     def dummy_fn(*_, **__):
         pass
@@ -268,8 +308,8 @@ def test_subscribe_to_trade_updates_non_master_raises(non_master_broker):
     def dummy_fn(*_, **__):
         pass
 
-    with pytest.raises(AttributeError):
-        master_broker.subscribe_to_trade_updates(func=dummy_fn)
+    with pytest.raises(ValueError):
+        non_master_broker.subscribe_to_trade_updates(func=dummy_fn)
 
 
 def test_subscribe_to_tws_trade_updates(
@@ -280,7 +320,7 @@ def test_subscribe_to_tws_trade_updates(
 ):
     open_orders = OrderedDict()
 
-    def log_order_status(status_: TradeStatus):
+    def log_order_status(trade_: Trade, status_: TradeStatus):
         order_id = status_.order_id
         if order_id not in open_orders:
             open_orders[order_id] = status_
@@ -303,6 +343,64 @@ def test_subscribe_to_tws_trade_updates(
     assert status.filled + status.remaining == 1
 
 
+def test_subscribe_to_position_updates_non_master_fails(
+    non_master_ib_test_broker,
+):
+    def dummy_fn(*_, **__):
+        pass
+
+    with pytest.raises(ValueError):
+        non_master_broker.subscribe_to_position_updates(func=dummy_fn)
+
+
+def test_subscribe_to_tws_position_updates(
+    master_broker,
+    non_master_ib_test_broker,
+    ib_stk_contract_spy,
+    ib_mkt_buy_order_1,
+    ib_mkt_sell_order_1,
+):
+    from ib_insync import OrderStatus
+
+    first_updates = []
+    second_updates = []
+
+    master_broker.subscribe_to_position_updates(
+        func=lambda t: first_updates.append(t),
+    )
+
+    trade = non_master_ib_test_broker.placeOrder(
+        contract=ib_stk_contract_spy, order=ib_mkt_buy_order_1,
+    )
+    while trade.orderStatus.status not in OrderStatus.DoneStates:
+        non_master_ib_test_broker.sleep(1)
+
+    assert len(first_updates) != 0
+    assert len(second_updates) == 0
+
+    update = first_updates[-1]
+    update_con = update.contract
+
+    assert update_con.symbol == ib_stk_contract_spy.symbol
+
+    master_broker.subscribe_to_position_updates(
+        func=lambda t: second_updates.append(t),
+    )
+
+    trade = non_master_ib_test_broker.placeOrder(
+        contract=ib_stk_contract_spy, order=ib_mkt_sell_order_1,
+    )
+    while trade.orderStatus.status not in OrderStatus.DoneStates:
+        non_master_ib_test_broker.sleep(1)
+
+    assert len(second_updates) != 0
+
+    f_update = first_updates[-1]
+    s_update = second_updates[-1]
+
+    assert f_update == s_update
+
+
 def request_manual_input(msg):
     from tkinter import messagebox
 
